@@ -109,18 +109,8 @@ class Command:
         value = value / 100.0
         self.api.feedrate(value)
 
-    def set_axis_offset_all(self, data):
-        for x in range(0, len(self.father.framework.machine.axes)):
-            key = self.father.framework.machine.get_axis_name(x)
-            self.set_axis_offset({"id": key, "p_name": data["p_name"], "value": data["value"]})
-
     def set_axis_offset(self, data):
-        axis = data["id"]
-        length = float(data["value"])
-        p_name = data["p_name"]
-        command = 'G10 L20 ' + p_name + ' ' + axis + str(length)
-        self.set_mdi(command)
-        self.set_mode(linuxcnc.MODE_MANUAL, 0.5)
+        self.api.offset(data["name"], x=float(data["x"]), y=float(data["y"]), z=float(data["z"]))
 
     def home_all(self):
         self.set_teleop_enable(0)
